@@ -28,6 +28,8 @@ from google.oauth2 import service_account  # type: ignore
 from google.cloud.firestore_v1.types import document
 from google.cloud.firestore_v1.types import document as gf_document
 from google.cloud.firestore_v1.types import firestore
+from google.cloud.location import locations_pb2  # type: ignore
+from google.longrunning import operations_pb2
 from google.protobuf import empty_pb2  # type: ignore
 
 try:
@@ -282,6 +284,23 @@ class FirestoreTransport(abc.ABC):
                 default_timeout=300.0,
                 client_info=client_info,
             ),
+            self.run_aggregation_query: gapic_v1.method.wrap_method(
+                self.run_aggregation_query,
+                default_retry=retries.Retry(
+                    initial=0.1,
+                    maximum=60.0,
+                    multiplier=1.3,
+                    predicate=retries.if_exception_type(
+                        core_exceptions.DeadlineExceeded,
+                        core_exceptions.InternalServerError,
+                        core_exceptions.ResourceExhausted,
+                        core_exceptions.ServiceUnavailable,
+                    ),
+                    deadline=300.0,
+                ),
+                default_timeout=300.0,
+                client_info=client_info,
+            ),
             self.partition_query: gapic_v1.method.wrap_method(
                 self.partition_query,
                 default_retry=retries.Retry(
@@ -468,6 +487,18 @@ class FirestoreTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def run_aggregation_query(
+        self,
+    ) -> Callable[
+        [firestore.RunAggregationQueryRequest],
+        Union[
+            firestore.RunAggregationQueryResponse,
+            Awaitable[firestore.RunAggregationQueryResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
     @property
     def partition_query(
         self,
@@ -528,6 +559,39 @@ class FirestoreTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def list_operations(
+        self,
+    ) -> Callable[
+        [operations_pb2.ListOperationsRequest],
+        Union[
+            operations_pb2.ListOperationsResponse,
+            Awaitable[operations_pb2.ListOperationsResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def get_operation(
+        self,
+    ) -> Callable[
+        [operations_pb2.GetOperationRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def cancel_operation(
+        self,
+    ) -> Callable[[operations_pb2.CancelOperationRequest], None,]:
+        raise NotImplementedError()
+
+    @property
+    def delete_operation(
+        self,
+    ) -> Callable[[operations_pb2.DeleteOperationRequest], None,]:
+        raise NotImplementedError()
+
     @property
     def kind(self) -> str:
         raise NotImplementedError()
